12. RQL logs — CubicWeb 3.11.0

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »
- Administration »

# 12. RQL logs

You can configure the CubicWeb instance to keep a log of the queries executed against your database. To do so, edit the configuration file of your instance `.../etc/cubicweb.d/myapp/all-in-one.conf` and uncomment the variable `query-log-file`:

    # web instance query log file
    query-log-file=/tmp/rql-myapp.log

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »
- Administration »